@@ -5,55 +5,36 @@ use DBIx::Inspector;
 use Teng::Schema;
 use Teng::Schema::Table;
 use Carp ();
-use Class::Load ();
 
 sub load {
     my $class = shift;
     my %args = @_==1 ? %{$_[0]} : @_;
 
+    my $dbh = $args{dbh} or Carp::croak("missing mandatory parameter 'dbh'");
     my $namespace = $args{namespace} or Carp::croak("missing mandatory parameter 'namespace'");
 
-    Class::Load::load_optional_class($namespace) or do {
-        # make teng class automatically
-        require Teng;
-        no strict 'refs'; @{"$namespace\::ISA"} = ('Teng');
-    };
-
-    my $teng = $namespace->new(%args);
-    my $dbh = $teng->dbh;
-    unless ($dbh) {
-        Carp::croak("missing mandatory parameter 'dbh' or 'connect_info'");
-    }
-
-    my $schema = Teng::Schema->new(namespace => $args{namespace});
+    my $schema = Teng::Schema->new();
 
     my $inspector = DBIx::Inspector->new(dbh => $dbh);
     for my $table_info ($inspector->tables) {
 
         my $table_name = $table_info->name;
         my @table_pk   = map { $_->name } $table_info->primary_key;
-        my @col_names;
-        my %sql_types;
-        for my $col ($table_info->columns) {
-            push @col_names, $col->name;
-            $sql_types{$col->name} = $col->data_type;
-        }
+        my @col_names  = map { $_->name } $table_info->columns;
 
         $schema->add_table(
             Teng::Schema::Table->new(
                 columns      => \@col_names,
                 name         => $table_name,
                 primary_keys => \@table_pk,
-                sql_types    => \%sql_types,
-                inflators    => [],
-                deflators    => [],
+                sql_types    => {},
+                inflators    => {},
+                deflators    => {},
                 row_class    => join '::', $namespace, 'Row', Teng::Schema::camelize($table_name),
             )
         );
     }
-
-    $teng->schema($schema);
-    return $teng;
+    return $schema;
 }
 
 1;
@@ -68,10 +49,14 @@ Teng::Schema::Loader - Dynamic Schema Loader
     use Teng;
     use Teng::Schema::Loader;
 
-    my $teng = Teng::Schema::Loader->load(
+    my $schema = Teng::Schema::Loader->load(
         dbh       => $dbh,
         namespace => 'MyAPP::DB'
     );
+    my $teng = Teng->new(
+        dbh    => $dbh,
+        schema => $schema
+    );
 
 =head1 DESCRIPTION
 
